
# Coomer Xtractor

This is a simple pip package that allows you to downlaod content from coomer.su. Coomer is a public archiver for onlyfans and fansly accounts. You are then able to create your own archive of the account.



## Badges


[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)

## License

[MIT](https://choosealicense.com/licenses/mit/)


## Roadmap

- Add better duplicate detection

- Add facial recognition

- Add better profile handling and adjustments

- Add a search feature or lookup to avoid requireing urls



## Contributing

Contributions are always welcome!

See `contributing.md` for ways to get started.

Please adhere to this project's `code of conduct`.


## Optimizations

This code was created to be easy to use and easy to ensure that you have the most up to date version of the archive. It keeps a database record of urls that have already been downloaded so thaty ou can avoid downloading the same posts over and over. There will be more coming in the future that will allow it to hash individual images and videos to determine if they have already been saved or not to compeletely eliminate duplicates.


## FAQ

#### Can I scrape onlyfans or fansly with this?

No, this scraper only works with coomer.su

#### Does this scraper cost anything?

No, there is no fee to use this software. Donations are welcome (see the donations section) but are not required.




## Installation

Install Coomer Xtractor with pip

```bash
  pip install coomer_xtractor
```


    
## Deployment

To deploy this project run

```bash
  coomer
```


## Usage/Examples

```bash
coomer
```

Once you type coomer in the terminal you will see a menu popup, just follow the prompts!


## Authors

- [@taux1c](https://www.github.com/taux1c)





## Feedback

If you have any feedback, please reach out to us at taux1c.software@proton.me

